package com.hs.admin.job;


import com.hs.admin.bean.DataBase;
import com.hs.admin.bean.MqData;
import com.hs.admin.bean.Student;
import com.hs.admin.bean.SysTask;
import com.hs.admin.dao.SysTaskDao;
import com.hs.admin.util.DynamicDataBaseUtil;
import com.hs.admin.util.JsonUtils;
import com.zaxxer.hikari.HikariDataSource;
import org.quartz.*;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.jdbc.core.BeanPropertyRowMapper;
import org.springframework.jdbc.core.namedparam.NamedParameterJdbcTemplate;
import org.springframework.stereotype.Component;
import org.springframework.util.CollectionUtils;

import javax.annotation.Resource;
import java.io.IOException;
import java.io.InputStream;
import java.util.List;
import java.util.Properties;

@DisallowConcurrentExecution
@Component
public class TestJob implements Job {
    @Resource
    RabbitTemplate rabbitTemplate;
    @Resource
    SysTaskDao sysTaskDao;

    @Override
    public void execute(JobExecutionContext jobExecutionContext) throws JobExecutionException {
        JobDataMap jobDataMap = jobExecutionContext.getTrigger().getJobDataMap();
        System.out.println(JsonUtils.beanToJson(jobDataMap));
        String triggerTask = jobDataMap.get("triggerTask").toString();
        SysTask sysTask = JsonUtils.jsonToBean(triggerTask, SysTask.class);
        MqData mqData = JsonUtils.jsonToBean(sysTask.getContent(), MqData.class);
        String guid = mqData.getGuid();
        String jcbId = mqData.getJcbId();
        String url = mqData.getUrl();
        Integer type = mqData.getType();
        String jobName = mqData.getJobName();
        String content = mqData.getContent();
        //根据jcbId选择db操作todo
        DataBase dataBase = getDataBaseInfo(jcbId);
        HikariDataSource dataSource = null;
        try {
            dataSource = DynamicDataBaseUtil.configure(dataBase);
            NamedParameterJdbcTemplate jdbcTemplate = new NamedParameterJdbcTemplate(dataSource);
            List<Student> students = jdbcTemplate.query(content, new BeanPropertyRowMapper<>(Student.class));
            System.out.println(">>>>>>>>>>>" + JsonUtils.beanToJson(students));
            if (!CollectionUtils.isEmpty(students)) {
                for (Student student : students) {
                    //将db返回结果发送消息队列
//                    rabbitTemplate.convertAndSend(RabbitMqConfig.ITEM_TOPIC_EXCHANGE,"",j);
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            //每次用完记得关闭连接
            dataSource.close();
        }


//
//        String content = "00...........这是另一个定时任务!" + LocalDateTime.now();
//        System.out.println("00...........这是另一个定时任务!" + LocalDateTime.now());
//        String path = "/Users/macbookpro/Documents/";
//        String date = LocalDate.now().toString();
//        String className = this.getClass().getSimpleName();
//        path = path + date;
//        File file = new File(path);
//        if (!file.exists()) {
//            file.mkdirs();
//        }
//        String fileName = path + "/" + className + ".txt";
//        FileUtil.writeFile(fileName, content);
    }

    /**
     * @description: 读取本地配置文件
     * @param: jcbId
     * @return: DataBase
     * @author: XieHeng
     * @date: 2021/5/7 4:11 下午
     */
    private DataBase readProperties(String jcbId) {
        InputStream inputStream = this.getClass().getClassLoader().getResourceAsStream("dbconfig/db.properties");
        Properties properties = new Properties();
        try {
            properties.load(inputStream);
            String host = properties.getProperty(jcbId + "_db_host");
            String port = properties.getProperty(jcbId + "_db_port");
            String username = properties.getProperty(jcbId + "_db_username");
            String password = properties.getProperty(jcbId + "_db_password");
            String dbName = properties.getProperty(jcbId + "_db_name");
            String type = properties.getProperty(jcbId + "_db_type");
            String driver = "";
            String url = "";
            switch (type) {
                //1sqlserver,2mysql,3oracle
                case "1":
                    driver = "com.microsoft.sqlserver.jdbc.SQLServerDriver";
                    url = "jdbc:sqlserver://" + host + ":" + port + ";DatabaseName=" + dbName;
                    break;
                case "2":
                    driver = "com.mysql.cj.jdbc.Driver";
                    url = "jdbc:mysql://" + host + ":" + port + "/" + dbName;
                    break;
                case "3":
                    driver = "oracle.jdbc.OracleDriver";
                    url = "jdbc:oracle:thin:@//" + host + ":" + port + "/" + dbName;
                    break;
                default:
                    break;
            }
            return new DataBase(host, port, dbName, username, password, type, driver, url);
        } catch (IOException e) {
            e.printStackTrace();
        }
        return null;
    }

    private DataBase getDataBaseInfo(String jcbId) {
        DataBase dataBase = sysTaskDao.getDbInfo(jcbId);
        String type = dataBase.getDbType();
        String host = dataBase.getHost();
        String dbName = dataBase.getName();
        String port = dataBase.getPort();
        String driver = null;
        String url = null;
        switch (type) {
            //1sqlserver,2mysql,3oracle
            case "1":
                driver = "com.microsoft.sqlserver.jdbc.SQLServerDriver";
                url = "jdbc:sqlserver://" + host + ":" + port + ";DatabaseName=" + dbName;
                break;
            case "2":
                driver = "com.mysql.cj.jdbc.Driver";
                url = "jdbc:mysql://" + host + ":" + port + "/" + dbName;
                break;
            case "3":
                driver = "oracle.jdbc.OracleDriver";
                url = "jdbc:oracle:thin:@//" + host + ":" + port + "/" + dbName;
                break;
            default:
                break;
        }
        dataBase.setDbDriver(driver);
        dataBase.setUrl(url);
        return dataBase;
    }
}
